@@ -25,6 +25,10 @@
 
 #define FUSE_USE_VERSION 31
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #define _GNU_SOURCE
 
 #ifdef linux
@@ -51,8 +55,6 @@
 
 #include "passthrough_helpers.h"
 
-static int fill_dir_plus = 0;
-
 static void *xmp_init(struct fuse_conn_info *conn,
 		      struct fuse_config *cfg)
 {
@@ -130,7 +132,7 @@ static int xmp_readdir(const char *path, void *buf, fuse_fill_dir_t filler,
 		memset(&st, 0, sizeof(st));
 		st.st_ino = de->d_ino;
 		st.st_mode = de->d_type << 12;
-		if (filler(buf, de->d_name, &st, 0, fill_dir_plus))
+		if (filler(buf, de->d_name, &st, 0, 0))
 			break;
 	}
 
@@ -475,10 +477,8 @@ static ssize_t xmp_copy_file_range(const char *path_in,
 	if (res == -1)
 		res = -errno;
 
-	if (fi_out == NULL)
-		close(fd_out);
-	if (fi_in == NULL)
-		close(fd_in);
+	close(fd_in);
+	close(fd_out);
 
 	return res;
 }
@@ -549,18 +549,6 @@ static const struct fuse_operations xmp_oper = {
 
 int main(int argc, char *argv[])
 {
-	enum { MAX_ARGS = 10 };
-	int i,new_argc;
-	char *new_argv[MAX_ARGS];
-
 	umask(0);
-			/* Process the "--plus" option apart */
-	for (i=0, new_argc=0; (i<argc) && (new_argc<MAX_ARGS); i++) {
-		if (!strcmp(argv[i], "--plus")) {
-			fill_dir_plus = FUSE_FILL_DIR_PLUS;
-		} else {
-			new_argv[new_argc++] = argv[i];
-		}
-	}
-	return fuse_main(new_argc, new_argv, &xmp_oper, NULL);
+	return fuse_main(argc, argv, &xmp_oper, NULL);
 }
