@@ -51,9 +51,6 @@ enum fuse_readdir_flags {
 	FUSE_READDIR_PLUS = (1 << 0)
 };
 
-/**
- * Readdir flags, passed to fuse_fill_dir_t callback.
- */
 enum fuse_fill_dir_flags {
 	/**
 	 * "Plus" mode: all file attributes are valid
@@ -77,7 +74,7 @@ enum fuse_fill_dir_flags {
  * 
  * @param buf the buffer passed to the readdir() operation
  * @param name the file name of the directory entry
- * @param stbuf file attributes, can be NULL
+ * @param stat file attributes, can be NULL
  * @param off offset of the next entry or zero
  * @param flags fill flags
  * @return 1 if buffer is full, zero otherwise
@@ -124,7 +121,7 @@ struct fuse_config {
 	/**
 	 * The timeout in seconds for which a negative lookup will be
 	 * cached. This means, that if file did not exist (lookup
-	 * returned ENOENT), the lookup will only be redone after the
+	 * retuned ENOENT), the lookup will only be redone after the
 	 * timeout, and the file/directory will be assumed to not
 	 * exist until then. A value of zero means that negative
 	 * lookups are not cached.
@@ -247,14 +244,6 @@ struct fuse_config {
 	 */
 	int auto_cache;
 
-	/**
-	 * By default, fuse waits for all pending writes to complete
-	 * and calls the FLUSH operation on close(2) of every fuse fd.
-	 * With this option, wait and FLUSH are not done for read-only
-	 * fuse fd, similar to the behavior of NFS/SMB clients.
-	 */
-	int no_rofd_flush;
-
 	/**
 	 * The timeout in seconds for which file attributes are cached
 	 * for the purpose of checking if auto_cache should flush the
@@ -372,14 +361,14 @@ struct fuse_operations {
 
 	/** Change the permission bits of a file
 	 *
-	 * `fi` will always be NULL if the file is not currently open, but
+	 * `fi` will always be NULL if the file is not currenlty open, but
 	 * may also be NULL if the file is open.
 	 */
 	int (*chmod) (const char *, mode_t, struct fuse_file_info *fi);
 
 	/** Change the owner and group of a file
 	 *
-	 * `fi` will always be NULL if the file is not currently open, but
+	 * `fi` will always be NULL if the file is not currenlty open, but
 	 * may also be NULL if the file is open.
 	 *
 	 * Unless FUSE_CAP_HANDLE_KILLPRIV is disabled, this method is
@@ -389,7 +378,7 @@ struct fuse_operations {
 
 	/** Change the size of a file
 	 *
-	 * `fi` will always be NULL if the file is not currently open, but
+	 * `fi` will always be NULL if the file is not currenlty open, but
 	 * may also be NULL if the file is open.
 	 *
 	 * Unless FUSE_CAP_HANDLE_KILLPRIV is disabled, this method is
@@ -563,28 +552,15 @@ struct fuse_operations {
 	 * passes non-zero offset to the filler function.  When the buffer
 	 * is full (or an error happens) the filler function will return
 	 * '1'.
-	 *
-	 * When FUSE_READDIR_PLUS is not set, only some parameters of the
-	 * fill function (the fuse_fill_dir_t parameter) are actually used:
-	 * The file type (which is part of stat::st_mode) is used. And if
-	 * fuse_config::use_ino is set, the inode (stat::st_ino) is also
-	 * used. The other fields are ignored when FUSE_READDIR_PLUS is not
-	 * set.
 	 */
 	int (*readdir) (const char *, void *, fuse_fill_dir_t, off_t,
 			struct fuse_file_info *, enum fuse_readdir_flags);
 
 	/** Release directory
-	 *
-	 * If the directory has been removed after the call to opendir, the
-	 * path parameter will be NULL.
 	 */
 	int (*releasedir) (const char *, struct fuse_file_info *);
 
 	/** Synchronize directory contents
-	 *
-	 * If the directory has been removed after the call to opendir, the
-	 * path parameter will be NULL.
 	 *
 	 * If the datasync parameter is non-zero, then only the user data
 	 * should be flushed, not the meta data
@@ -672,7 +648,7 @@ struct fuse_operations {
 	 * This supersedes the old utime() interface.  New applications
 	 * should use this.
 	 *
-	 * `fi` will always be NULL if the file is not currently open, but
+	 * `fi` will always be NULL if the file is not currenlty open, but
 	 * may also be NULL if the file is open.
 	 *
 	 * See the utimensat(2) man page for details.
@@ -688,10 +664,6 @@ struct fuse_operations {
 	 */
 	int (*bmap) (const char *, size_t blocksize, uint64_t *idx);
 
-#if FUSE_USE_VERSION < 35
-	int (*ioctl) (const char *, int cmd, void *arg,
-		      struct fuse_file_info *, unsigned int flags, void *data);
-#else
 	/**
 	 * Ioctl
 	 *
@@ -708,6 +680,10 @@ struct fuse_operations {
 	 * Note : the unsigned long request submitted by the application
 	 * is truncated to 32 bits.
 	 */
+#if FUSE_USE_VERSION < 35
+	int (*ioctl) (const char *, int cmd, void *arg,
+		      struct fuse_file_info *, unsigned int flags, void *data);
+#else
 	int (*ioctl) (const char *, unsigned int cmd, void *arg,
 		      struct fuse_file_info *, unsigned int flags, void *data);
 #endif
@@ -880,7 +856,7 @@ struct fuse_context {
  *   4: Mounting failed
  *   5: Failed to daemonize (detach from session)
  *   6: Failed to set up signal handlers
- *   7: An error occurred during the life of the file system
+ *   7: An error occured during the life of the file system
  *
  * @param argc the argument counter passed to the main() function
  * @param argv the argument vector passed to the main() function
@@ -948,15 +924,8 @@ struct fuse *fuse_new_30(struct fuse_args *args, const struct fuse_operations *o
 			 size_t op_size, void *private_data);
 #define fuse_new(args, op, size, data) fuse_new_30(args, op, size, data)
 #else
-#if (defined(LIBFUSE_BUILT_WITH_VERSIONED_SYMBOLS))
 struct fuse *fuse_new(struct fuse_args *args, const struct fuse_operations *op,
 		      size_t op_size, void *private_data);
-#else /* LIBFUSE_BUILT_WITH_VERSIONED_SYMBOLS */
-struct fuse *fuse_new_31(struct fuse_args *args,
-		      const struct fuse_operations *op,
-		      size_t op_size, void *user_data);
-#define fuse_new(args, op, size, data) fuse_new_31(args, op, size, data)
-#endif /* LIBFUSE_BUILT_WITH_VERSIONED_SYMBOLS */
 #endif
 
 /**
@@ -1015,13 +984,6 @@ int fuse_loop(struct fuse *f);
  */
 void fuse_exit(struct fuse *f);
 
-#if FUSE_USE_VERSION < 32
-int fuse_loop_mt_31(struct fuse *f, int clone_fd);
-#define fuse_loop_mt(f, clone_fd) fuse_loop_mt_31(f, clone_fd)
-#elif FUSE_USE_VERSION < FUSE_MAKE_VERSION(3, 12)
-int fuse_loop_mt_32(struct fuse *f, struct fuse_loop_config *config);
-#define fuse_loop_mt(f, config) fuse_loop_mt_32(f, config)
-#else
 /**
  * FUSE event loop with multiple threads
  *
@@ -1048,19 +1010,18 @@ int fuse_loop_mt_32(struct fuse *f, struct fuse_loop_config *config);
  * in the callback function of fuse_operations is also thread-safe.
  *
  * @param f the FUSE handle
- * @param config loop configuration, may be NULL and defaults will be used then
+ * @param config loop configuration
  * @return see fuse_session_loop()
  *
  * See also: fuse_loop()
  */
-#if (defined(LIBFUSE_BUILT_WITH_VERSIONED_SYMBOLS))
-int fuse_loop_mt(struct fuse *f, struct fuse_loop_config *config);
+#if FUSE_USE_VERSION < 32
+int fuse_loop_mt_31(struct fuse *f, int clone_fd);
+#define fuse_loop_mt(f, clone_fd) fuse_loop_mt_31(f, clone_fd)
 #else
-#define fuse_loop_mt(f, config) fuse_loop_mt_312(f, config)
-#endif /* LIBFUSE_BUILT_WITH_VERSIONED_SYMBOLS */
+int fuse_loop_mt(struct fuse *f, struct fuse_loop_config *config);
 #endif
 
-
 /**
  * Get the current context
  *
